@@ -248,7 +248,10 @@ class RoborockFanSpeedP10(RoborockFanPowerCode):
 
 class RoborockFanSpeedS8MaxVUltra(RoborockFanPowerCode):
     off = 105
+    quiet = 101
     balanced = 102
+    turbo = 103
+    max = 104
     custom = 106
     max_plus = 108
     smart_mode = 110
@@ -324,6 +327,8 @@ class RoborockMopIntensityS8MaxVUltra(RoborockMopIntensityCode):
     low = 201
     medium = 202
     high = 203
+    custom = 204
+    max = 208
     smart_mode = 209
     custom_water_flow = 207
 
@@ -394,6 +399,7 @@ class RoborockDockWashTowelModeCode(RoborockEnum):
     light = 0
     balanced = 1
     deep = 2
+    smart = 10
 
 
 class RoborockCategory(Enum):
